index – BRDR - Aligning borders

# Function reference

## Aligner

Aligner class of the brdr package.

Aligner | Compares and aligns thematic geospatial data against a set of reference data.
AlignerResult | Stores and processes the results from the alignment operation.

## AlignerFeatures

Classes for the thematic and reference data to be used by the Aligner

AlignerFeatureCollection | A collection of AlignerFeature objects with spatial indexing and utility properties.
AlignerFeature | A container for a single thematic or reference feature within the aligner.

## Loaders

Loaders to load data

Loader | Abstract base class for all data loaders.
DictLoader | Loader that accepts data directly from Python dictionaries.
GeoJsonLoader | Base class for loaders dealing with GeoJSON-formatted data.
GeoJsonFileLoader | Loads GeoJSON data from a local file system.
GeoJsonUrlLoader | Loads GeoJSON data from a remote URL via HTTP GET.
OGCFeatureAPIReferenceLoader | Loader for OGC API - Features services.
WFSReferenceLoader | Loader for OGC Web Feature Service (WFS) version 2.0.0.

## Processors

Processor algorithms

BaseProcessor | Abstract base class for geometric alignment processors.
AlignerGeometryProcessor | Processor responsible for aligning thematic geometries to reference data.
DieussaertGeometryProcessor | Processor implementing the Dieussaert area-based alignment algorithm.
NetworkGeometryProcessor | Processor that aligns geometries based on a linear network.
SnapGeometryProcessor | Processor that aligns geometries by snapping them to the reference data.
TopologyProcessor | Processor that aligns geometries while preserving topological relationships.

## Enumerators

Enums used in the brdr package.

FullReferenceStrategy | Strategy for handling reference data coverage.
AlignerResultType | Format of the output dictionary.
OpenDomainStrategy | Strategies for processing thematic areas not covered by reference data.
DiffMetric | Metrics to quantify the change between thematic and reference data.
ProcessRemark | Status remarks added to processed features for auditing and debugging.
Evaluation | Classification of the alignment quality and reliability.
SnapStrategy | Geometric priority during snapping.
PredictionStrategy | Determines which prediction is selected as the primary result.
ProcessorID | Unique identifiers for the available alignment algorithms.

## Typings

Typings used in ‘brdr’

ProcessResult | A dictionary structure representing the output of a geometric alignment process.

## Configs

Configs used in ‘brdr’ Aligner & Processor

ProcessorConfig | Configuration for the geometric preprocessing of polygons in the brdr pipeline.
AlignerConfig | Configuration for the alignment and correction of spatial boundaries.

## GRB (Flanders-specific)

GRB (Flanders-specific) classes,methods, enumerators,…

loader.GRBActualLoader | Loader for the most recent version of GRB (Grootschalig Referentie Bestand).
loader.GRBFiscalParcelLoader | Loader for fiscal parcel data (Adpf) for a specific year.
loader.GRBSpecificDateParcelLoader | Loader for GRB parcel situations on a specific historical date.
grb.update_featurecollection_to_actual_grb | Update a thematic feature collection to the most recent version of the GRB.
utils.is_grb_changed | checks if a geometry is possibly affected by changes in the reference layer
utils.get_affected_ids_by_grb_change | Get a list of affected IDs by GRB-changes in a
enums.GRBType |

## OSM

OpenStreetMap (OSM) classes,methods, enumerators,…

loader.OSMLoader | Loader for OpenStreetMap (OSM) features based on specific tags.

## Visualization-functions (optional by pip install brdr[viz])

OpenStreetMap (OSM) classes,methods, enumerators,…

show_map | Display a grid of maps showing alignment results across different distances.
plot_difference_by_relevant_distance | Plot geometric differences across multiple features as a line graph.
animated_map | Create a synchronized animation of map changes and area statistics.
print_observation_of_aligner_results | Print a detailed comparison analysis for alignment results.